handlers

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2020 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AuthHandler

func AuthHandler(response http.ResponseWriter, request *http.Request)

AuthHandler handles all POST requests on the Auth route and expects email and uid in the request body. This route can be used to either register a new player or sign in an already registered player

Types

This section is empty.

Directories

Path Synopsis

Jump to