note

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 9, 2021 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddNoteHandler

func AddNoteHandler(response http.ResponseWriter, request *http.Request)

AddNoteHandler can be used by authenticated users to create notes

func DeleteNoteHandler

func DeleteNoteHandler(response http.ResponseWriter, request *http.Request)

DeleteNoteHandler is used to delete notes from database

func EditNoteHandler

func EditNoteHandler(response http.ResponseWriter, request *http.Request)

EditNoteHandler handles all request that modify the existing notes in the database

func GetNoteHandler

func GetNoteHandler(response http.ResponseWriter, request *http.Request)

GetNoteHandler can be used to retrive a single note

func GetNotesHandler

func GetNotesHandler(response http.ResponseWriter, request *http.Request)

GetNotesHandler sends back the users notes

Types

This section is empty.

Jump to