package
Version:
v0.1.3
Opens a new window with list of versions in this module.
Published: Jan 9, 2021
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
UserExists verifies if a user already exists
type User struct {
UID string `json:"uid" bson:"uid,omitempty"`
Email string `json:"email" bson:"email,omitempty"`
Labels []string `json:"labels" bson:"labels,omitempty"`
}
User struct represents the authenticated/registered user
Get retrives the registered user
Set is used to register a new user
Source Files
¶
Click to show internal directories.
Click to hide internal directories.