Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AuthHandler ¶
func AuthHandler(response http.ResponseWriter, request *http.Request)
AuthHandler handles all POST requests on the Auth route and expects email and uid in the request body. This route can be used to either register a new player or sign in an already registered player
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.